import React, { useState, useEffect } from "react";
import { makeStyles } from "@material-ui/core/styles";
import {
  Container,
  Grid,
  Paper,
  Card,
  Typography,
  Fab,
  Button,
} from "@material-ui/core";
import { statusCheckIn } from "../../api/user";
import { useHistory } from "react-router-dom";
import Alert from "@material-ui/lab/Alert";
import "./HomeView.css";

import ButtonCheckIn from "./ButtonCheckIn";

const HomeView = (props) => {
  const { user, onCheckIn, changeStatus, changeIdCheck } = props;

  const [status, setStatus] = useState("");
  let history = useHistory();

  useEffect(() => {
    getInfo();
  }, [changeStatus]);

  const getInfo = async () => {
    const res = await statusCheckIn({
      empCode: JSON.parse(localStorage.getItem("user")).code,
    });
    if (res.data && res.data.errorCode == 0) {
      if (res.data.data.notCheckInYet == 1) {
        setStatus(0);
      } else if (res.data.data.notCheckOutYet == 1) {
        setStatus(1);
        changeIdCheck(res.data.data.checkInID);
      } else if (res.data.data.doneCheck == 1) {
        setStatus(2);
      }
    } else if (res.status == 403 || res.status == 401) {
      localStorage.removeItem("TOKEN_KEY");
      localStorage.removeItem("user");
      setTimeout(() => {
        history.push("/");
      }, 100);
    } else {
      window.alert("Lỗi");
    }
  };

  const signOut = () => {
    localStorage.removeItem("TOKEN_KEY");
    localStorage.removeItem("user");
    setTimeout(() => {
      history.push("/");
    }, 100);
  };
  return (
    <Container fixed style={{ height: "100vh", position: "relative" }}>
      <div style={{ marginTop: 10 }} />
      <br />
      <div style={{ textAlign: "right" }}>
        <Button variant="contained" color="secondary" onClick={signOut}>
          Đăng xuất
        </Button>
      </div>
      <div style={{ textAlign: "center", fontSize: "35px", marginTop: "15px" }}>
        <Typography variant={"h4"} style={{ color: " #3399ff" }}>
          Chào mừng
        </Typography>
        <h6 style={{ fontSize: "30px", margin: "0px", color: " #3399ff" }}>
          {user ? user.name : ""}
        </h6>
      </div>
      <br />
      <Grid container style={{ height: "65%", justifyContent: "center" }}>
        <Fab
          aria-label="edit"
          style={{ width: "30vw", height: "30vw" }}
          onClick={() => {
            onCheckIn(status);
          }}
          className={
            status == 0 ? "checkin" : status == 1 ? "checkout" : "complete"
          }
        >
          <span style={{ fontSize: "3vw" }}>
            {status == 0
              ? "CHECK-IN"
              : status == 1
              ? "CHECK-OUT"
              : "Hoàn thành"}
          </span>
        </Fab>
      </Grid>
    </Container>
  );
};

export default HomeView;
