import React, { useState } from "react";
import Avatar from "@material-ui/core/Avatar";
import Button from "@material-ui/core/Button";
import CssBaseline from "@material-ui/core/CssBaseline";
import TextField from "@material-ui/core/TextField";
import { FormHelperText, Link, Grid, Box, Typography } from "@material-ui/core";
import { useHistory } from "react-router-dom";
import LockOutlinedIcon from "@material-ui/icons/LockOutlined";
import { makeStyles } from "@material-ui/core/styles";
import Container from "@material-ui/core/Container";
import { loginApi } from "../../api/user";

function Copyright() {
  return (
    <Typography variant="body2" color="textSecondary" align="center">
      {"Copyright © "}
      <Link color="inherit" href="https://material-ui.com/">
        Your Website
      </Link>{" "}
      {new Date().getFullYear()}
      {"."}
    </Typography>
  );
}

const useStyles = makeStyles((theme) => ({
  paper: {
    display: "flex",
    flexDirection: "column",
    alignItems: "center",
  },
  avatar: {
    margin: theme.spacing(1),
    backgroundColor: theme.palette.secondary.main,
  },
  form: {
    width: "100%", // Fix IE 11 issue.
  },
  submit: {
    margin: theme.spacing(3, 0, 2),
  },
}));

const LoginScreen = () => {
  const classes = useStyles();
  let history = useHistory();
  const [state, setState] = useState({
    appcode: "Dcv",
    username: "",
    password: "",
  });

  const [helperText, sethelperText] = useState("");
  const onLogin = async () => {
    if (state.username === "" || state.password === "") {
      sethelperText("");
      sethelperText("Cần phải điền đầy đủ email và password");
    } else {
      sethelperText("");
      const res = await loginApi(state);

      if (res.data && res.data.errorCode === 0) {
        localStorage.setItem("TOKEN_KEY", res.data.data.accessToken);
        localStorage.setItem(
          "user",
          JSON.stringify({
            name: res.data.data.fullName,
            code: res.data.data.code,
          })
        );
        history.push({
          pathname: "/home",
          state: { code: res.data.data.code, fullName: res.data.data.fullName },
        });
      } else if (res.data && res.data.errorCode === 1) {
        sethelperText("");
        sethelperText("Sai email hoặc mật khẩu");
      }
    }
  };

  return (
    <div style={{ height: "100vh" }}>
      <Container component="main" maxWidth="xs">
        <CssBaseline />
        <div className={classes.paper}>
          <img
            style={{ width: 200, height: 100, marginTop: 10, marginBottom: 10 }}
            src="/logo-DCV.png"
          />
          <Typography color={"primary"} component="h1" variant="h5">
            ĐĂNG NHẬP
          </Typography>
          <TextField
            variant="outlined"
            margin="normal"
            required
            fullWidth
            label="Email"
            autoComplete="email"
            onChange={(e) => {
              setState({
                ...state,
                username: e.target.value,
              });
            }}
            autoFocus
          />
          <TextField
            variant="outlined"
            margin="normal"
            required
            fullWidth
            label="Mật khẩu"
            type="password"
            onChange={(e) => {
              setState({
                ...state,
                password: e.target.value,
              });
            }}
            autoComplete="current-password"
          />
          <div style={{ width: "100%" }}>
            <FormHelperText
              style={{ marginLeft: "16px", color: "red", fontSize: "13px" }}
            >
              {helperText}
            </FormHelperText>
          </div>

          <Button
            type="submit"
            fullWidth
            variant="contained"
            color="primary"
            className={classes.submit}
            onClick={onLogin}
          >
            Đăng nhập
          </Button>
          <Grid container>
            <Grid item xs>
              <Link href="#" variant="body2">
                Quên mật khẩu?
              </Link>
            </Grid>
          </Grid>
        </div>
        <Box mt={8}>
          <Copyright />
        </Box>
      </Container>
    </div>
  );
};

export default LoginScreen;
